@@ -80,7 +80,7 @@ def _get_detector_unit(detector_type, geotyp):
         SHDetType.dose_gy: dose_gy_units,
         SHDetType.dlet: ("keV/um", "dose-averaged LET"),
         SHDetType.tlet: ("keV/um", "track-averaged LET"),
-        SHDetType.avg_energy: ("MeV", "Average energy"),
+        SHDetType.avg_energy: ("MeV/nucleon", "Average kinetic energy"),
         SHDetType.avg_beta: ("(dimensionless)", "Average beta"),
         SHDetType.material: ("(nil)", "Material number"),
         SHDetType.alanine: alanine_units,
@@ -92,6 +92,7 @@ def _get_detector_unit(detector_type, geotyp):
         SHDetType.q: ("(nil)", "beam quality Q"),
         SHDetType.flu_char: ("cm^-2/primary", "Charged particle fluence"),
         SHDetType.flu_neut: ("cm^-2/primary", "Neutral particle fluence"),
+        SHDetType.flu_neqv: ("cm^-2/primary", "1 MeV eqv. neutron fluence"),
         SHDetType.let: ("keV/um", "LET"),
         SHDetType.angle: ("radians", "Angle"),
         SHDetType.zone: ("(dimensionless)", "Zone#"),
@@ -243,6 +244,7 @@ class SHBinaryReader:
     """
     Reads binary output files generated by SHIELD-HIT12A code.
     """
+
     def __init__(self, filename):
         self.filename = filename
 
@@ -289,6 +291,7 @@ class _SHBinaryReader0p6:
     """
     Binary format reader from version >= 0.6
     """
+
     def __init__(self, filename):
         self.filename = filename
 
@@ -504,6 +507,7 @@ class _SHBinaryReader0p1:
     """
     Binary format reader from 0.1 <= version <= 0.6
     """
+
     def __init__(self, filename):
         self.filename = filename
 
@@ -630,16 +634,16 @@ class _SHBinaryReader0p1:
             zmax = 0.0
 
         if detector.geotyp in {SHGeoType.plane, SHGeoType.dplane}:
-                # special case for plane scoring, according to documentation we have:
-                #  xmin, ymin, zmin = Sx, Sy, Sz (point on the plane)
-                #  xmax, ymax, zmax = nx, ny, nz (normal vector)
-                # to avoid situation where i.e. xmax < xmin (corresponds to nx < Sx)
-                # we store only point on the plane
-                detector.sx, detector.sy, detector.sz = xmin, ymin, zmin
-                detector.nx, detector.ny, detector.nz = xmax, ymax, zmax
-                xmax = xmin
-                ymax = ymin
-                zmax = zmin
+            # special case for plane scoring, according to documentation we have:
+            #  xmin, ymin, zmin = Sx, Sy, Sz (point on the plane)
+            #  xmax, ymax, zmax = nx, ny, nz (normal vector)
+            # to avoid situation where i.e. xmax < xmin (corresponds to nx < Sx)
+            # we store only point on the plane
+            detector.sx, detector.sy, detector.sz = xmin, ymin, zmin
+            detector.nx, detector.ny, detector.nz = xmax, ymax, zmax
+            xmax = xmin
+            ymax = ymin
+            zmax = zmin
 
         xunit, xname = _get_mesh_units(detector, 0)
         yunit, yname = _get_mesh_units(detector, 1)
@@ -680,6 +684,7 @@ class SHTextReader:
     """
     Reads plain text files with data saved by binary-to-ascii converter.
     """
+
     def __init__(self, filename):
         self.filename = filename
 
